@@ -1,4 +1,4 @@
-//$Id: app-res.cc,v 1.26 2005/10/08 16:16:09 cactus Exp $ -*- c++ -*-
+//$Id: app-res.cc,v 1.27 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "app-res.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "ui.h"
 
