@@ -1,6 +1,6 @@
-//$Id: bitmap-res-ops.h,v 1.3 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: bitmap-res-ops.h,v 1.5 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -34,11 +34,11 @@ namespace Guikachu
                 serial_t         bitmap_serial;
                 Glib::ustring    op_label;
 
-                Magick::Image old_image, new_image;
+                Resources::Bitmap::ImageData old_image, new_image;
                 
             public:
-		ImageChangeOp (Resources::Bitmap   *bitmap,
-                               const Magick::Image &old_image);
+		ImageChangeOp (Resources::Bitmap                  *bitmap,
+                               const Resources::Bitmap::ImageData &old_image);
 		virtual ~ImageChangeOp () {};
 		
 		void undo ();
