@@ -1,4 +1,4 @@
-//$Id: bitmap-res.cc,v 1.15 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: bitmap-res.cc,v 1.18 2005/11/27 18:24:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,8 @@
 #include "io/io.h"
 #include "io/bmp-saver.h"
 
+#include "ui.h"
+
 #include <gdkmm/pixbufloader.h>
 
 using namespace Guikachu;
@@ -33,34 +35,42 @@ Resources::Bitmap::Bitmap (ResourceManager   *manager,
 {
 }
 
+#include <iostream>
+
 void Resources::Bitmap::load_file (const Glib::ustring &uri)
 {
-    unsigned char *data = 0;
-    Gnome::Vfs::FileSize len;
+    unsigned char  *data = 0;
+    IO::filesize_t  len;
     
     try {
         IO::load_uri (uri, data, len);
-    } catch (...) {
-        delete[] data;
-        return;
+        load_data (data, len, uri);
+    } catch (Glib::Exception &e) {
+        UI::show_error_io_load_resource (uri, id, e.what ());
     }
 
-    load_data (data, len);
     delete[] data;
 }
 
-void Resources::Bitmap::load_data (const unsigned char *data, size_t len)
+void Resources::Bitmap::load_data (const unsigned char *data, size_t len,
+                                   const Glib::ustring &src_hint)
 {
+    Glib::RefPtr<Gdk::PixbufLoader> loader = Gdk::PixbufLoader::create ();
+    bool closed = (len == 0);
+    
     try {
-	Glib::RefPtr<Gdk::PixbufLoader> loader = Gdk::PixbufLoader::create ();
 	loader->write ((unsigned char*)data, len);
 	loader->close ();
+        closed = true;
 	
 	ImageData pixbuf = loader->get_pixbuf ();
 
 	set_image (pixbuf);
     } catch (Glib::Exception &e) {
-        std::cerr << e.what () << std::endl;
+        if (!closed)
+            loader->close ();
+        
+        UI::show_error_io_load_resource (src_hint, id, e.what ());
     }
 }
 
@@ -69,8 +79,8 @@ void Resources::Bitmap::save_file_bmp (const Glib::ustring &uri) const
     if (!image)
 	return;
 
-    unsigned char *buf = 0;
-    Gnome::Vfs::FileSize len;
+    unsigned char  *buf = 0;
+    IO::filesize_t  len;
 
     try {
         IO::save_bmp (image, buf, len);
@@ -87,18 +97,10 @@ void Resources::Bitmap::save_data_png (unsigned char *&data, size_t &len) const
     len = 0;
     data = 0;
     
-    unsigned char *pixbuf_buf;
-    GError *error = 0;
+    gchar *pixbuf_buf;
     
-    gdk_pixbuf_save_to_buffer (image->gobj (), reinterpret_cast<char**>(&pixbuf_buf), &len,
-                               "png", &error, 0);
-    if (error)
-    {
-	g_error_free (error);
-	g_free (pixbuf_buf);
-
-        throw Glib::Error (error);        
-    }
+    image->save_to_buffer ((gchar*&)pixbuf_buf, (gsize&)len, "png",
+                           std::list<Glib::ustring>(), std::list<Glib::ustring>());
 
     data = new unsigned char[len];
     memcpy (data, pixbuf_buf, len);
@@ -117,7 +119,7 @@ void Resources::Bitmap::save_file_png (const Glib::ustring &uri) const
         save_data_png (buf, len);
 	IO::save_uri (uri, buf, len);
     } catch (Glib::Exception &e) {
-        ;
+        UI::show_error_io_save_resource (uri, id, e.what ());
     }
 
     delete[] buf;    
