@@ -1,4 +1,4 @@
-//$Id: bitmap-res.h,v 1.14 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: bitmap-res.h,v 1.15 2005/11/27 18:24:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -51,7 +51,7 @@ namespace Guikachu
 	    Property<BitmapType>   bitmap_type;
 
             void load_file     (const Glib::ustring &uri);
-	    void load_data     (const unsigned char *data, size_t len);
+	    void load_data     (const unsigned char *data, size_t len, const Glib::ustring &src_hint = "");
 
 	    void save_file_bmp (const Glib::ustring &uri) const;
             void save_data_png (unsigned char *&data, size_t &len) const;
