@@ -1,4 +1,4 @@
-//$Id: bitmap-win-helpers.cc,v 1.3 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: bitmap-win-helpers.cc,v 1.4 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "bitmap-win-helpers.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "property-ops-resource.h"
 
