@@ -1,6 +1,6 @@
-//$Id: bitmapfamily-res-ops.h,v 1.3 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-res-ops.h,v 1.5 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -45,12 +45,12 @@ namespace Guikachu
                 Glib::ustring op_label;
 
                 Resources::Bitmap::BitmapType type;
-                Magick::Image old_image, new_image;
+                Resources::Bitmap::ImageData old_image, new_image;
                 
             public:
-		ImageChangeOp (Resources::BitmapFamily       *res,
-                               Resources::Bitmap::BitmapType  type,
-                               const Magick::Image           &old_image);
+		ImageChangeOp (Resources::BitmapFamily            *res,
+                               Resources::Bitmap::BitmapType       type,
+                               const Resources::Bitmap::ImageData &old_image);
 		virtual ~ImageChangeOp () {};
 		
 		void undo ();
@@ -64,7 +64,7 @@ namespace Guikachu
                 Glib::ustring op_label;
 
                 Resources::Bitmap::BitmapType type;
-                Magick::Image old_image;
+                Resources::Bitmap::ImageData  old_image;
                 
             public:
 		ImageRemoveOp (Resources::BitmapFamily       *res,
