@@ -1,4 +1,4 @@
-//$Id: bitmapfamily-res.cc,v 1.12 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-res.cc,v 1.14 2005/11/27 18:24:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,6 +22,8 @@
 #include "io/bmp-saver.h"
 #include <gdkmm/pixbufloader.h>
 
+#include "ui.h"
+
 using namespace Guikachu;
 
 Resources::BitmapFamily::BitmapFamily (ResourceManager   *manager,
@@ -43,32 +45,40 @@ Resources::BitmapFamily::ImageData Resources::BitmapFamily::get_image (BitmapTyp
 
 void Resources::BitmapFamily::load_file (BitmapType type, const Glib::ustring &uri)
 {
-    unsigned char        *data = 0;
-    Gnome::Vfs::FileSize  len;
+    unsigned char  *data = 0;
+    IO::filesize_t  len;
 
     try {
+        
         IO::load_uri (uri, data, len);
-    } catch (...) {
-	delete[] data;
-	return;
+        load_data (type, data, len);
+        
+    } catch (Glib::Exception &e) {
+        UI::show_error_io_load_resource (uri, id, e.what ());
     }
-
-    load_data (type, data, len);
+    
     delete[] data;
 }
 
-void Resources::BitmapFamily::load_data (BitmapType type, const unsigned char *data, size_t len)
+void Resources::BitmapFamily::load_data (BitmapType type, const unsigned char *data, size_t len,
+                                         const Glib::ustring &src_hint)
 {
+    Glib::RefPtr<Gdk::PixbufLoader> loader = Gdk::PixbufLoader::create ();
+    bool closed = (len == 0);
+    
     try {
-	Glib::RefPtr<Gdk::PixbufLoader> loader = Gdk::PixbufLoader::create ();
 	loader->write (data, len);
 	loader->close ();
+        closed = true;
 	
 	ImageData pixbuf = loader->get_pixbuf ();
 	
 	set_image (type, pixbuf);
-    } catch (...) {
-	;
+    } catch (Glib::Exception &e) {
+        if (!closed)
+            loader->close ();
+        
+        UI::show_error_io_load_resource (src_hint, id, e.what ());
     }
 }
 
@@ -80,13 +90,13 @@ void Resources::BitmapFamily::save_file_bmp (BitmapType type, const Glib::ustrin
 	return;
     
     unsigned char *buf = 0;
-    Gnome::Vfs::FileSize len;
+    IO::filesize_t len;
 
     try {
         IO::save_bmp (image, buf, len);
 	IO::save_uri (uri, buf, len);
     } catch (Glib::Exception &e) {
-        ;
+        UI::show_error_io_save_resource (uri, id, e.what ());
     }
 
     delete[] buf;
@@ -101,18 +111,10 @@ void Resources::BitmapFamily::save_data_png (BitmapType type, unsigned char *&da
     if (!image)
         return;
     
-    unsigned char *pixbuf_buf;
-    GError *error = 0;
-    
-    gdk_pixbuf_save_to_buffer (image->gobj (), reinterpret_cast<char**>(&pixbuf_buf), &len,
-                               "png", &error, 0);
-    if (error)
-    {
-	g_error_free (error);
-	g_free (pixbuf_buf);
+    gchar *pixbuf_buf;
 
-        throw Glib::Error (error);        
-    }
+    image->save_to_buffer ((gchar*&)pixbuf_buf, (gsize&)len, "png",
+                           std::list<Glib::ustring>(), std::list<Glib::ustring>());
     
     data = new unsigned char[len];
     memcpy (data, pixbuf_buf, len);
@@ -128,7 +130,7 @@ void Resources::BitmapFamily::save_file_png (BitmapType type, const Glib::ustrin
         save_data_png (type, buf, len);
 	IO::save_uri (uri, buf, len);
     } catch (Glib::Exception &e) {
-        ;
+        UI::show_error_io_save_resource (uri, id, e.what ());
     }
 
     delete[] buf;
