@@ -1,4 +1,4 @@
-//$Id: bitmapfamily-win.cc,v 1.14 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-win.cc,v 1.16 2005/11/27 14:57:58 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,8 +19,7 @@
 #include "bitmapfamily-win.h"
 #include "bitmapfamily-res-ops.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include <sigc++/adaptors/bind_return.h>
 
@@ -49,6 +48,7 @@
 #include <gtkmm/scrolledwindow.h>
 
 #include "ui-gui.h"
+#include "widgets/filechooserdialog.h"
 
 using namespace Guikachu;
 
@@ -186,20 +186,14 @@ void GUI::BitmapFamilyWindow::update ()
 void GUI::BitmapFamilyWindow::load_cb ()
 {
     char *title = g_strdup_printf (_("Loading image file to %s"), res->id ().c_str ());
-    Gtk::FileChooserDialog file_chooser (window, title, Gtk::FILE_CHOOSER_ACTION_OPEN);
+    FileChooserDialog file_chooser (window, title, Gtk::FILE_CHOOSER_ACTION_OPEN);
     g_free (title);
     
-    file_chooser.add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-    file_chooser.add_button (Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT);
-    file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
-    
     Gtk::FileFilter filter;
     filter.set_name (_("Image files"));
     filter.add_custom (Gtk::FILE_FILTER_MIME_TYPE, sigc::ptr_fun (BitmapWindow_Helpers::is_image_file));
     file_chooser.add_filter (filter);
     
-    file_chooser.set_local_only (false);
-
     if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
     {
         UndoOp *op = new ResourceOps::BitmapFamilyOps::ImageChangeOp (res, type, res->get_image (type));
@@ -211,18 +205,13 @@ void GUI::BitmapFamilyWindow::load_cb ()
 void GUI::BitmapFamilyWindow::export_cb ()
 {
     char *title = g_strdup_printf (_("Exporting %s"), res->id ().c_str ());
-    Gtk::FileChooserDialog file_chooser (window, title, Gtk::FILE_CHOOSER_ACTION_SAVE);
+    FileChooserDialog file_chooser (window, title, Gtk::FILE_CHOOSER_ACTION_SAVE);
     g_free (title);
     
-    file_chooser.add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-    file_chooser.add_button (Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
-    file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
-    
     Gtk::FileFilter filter;
     filter.set_name (_("PNG files"));
     filter.add_mime_type ("image/png");
     file_chooser.add_filter (filter);
-    file_chooser.set_local_only (false);
 
     if (UI::confirm_save (file_chooser))
 	res->save_file_png (type, file_chooser.get_uri ());
