@@ -1,4 +1,4 @@
-//$Id: dialog-win.cc,v 1.41 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.cc,v 1.42 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "dialog-win.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include <gtkmm/menu.h>
 #include <gtkmm/notebook.h>
