@@ -1,4 +1,4 @@
-//$Id: edit-cut-and-paste.cc,v 1.15 2005/10/28 20:11:17 cactus Exp $ -*- c++ -*-
+//$Id: edit-cut-and-paste.cc,v 1.16 2005/11/25 00:13:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -45,9 +45,9 @@ namespace
     
     struct clipboard_contents_
     {
-	std::string       target;
-	unsigned char    *buffer;
-	GnomeVFSFileSize  length;
+	std::string     target;
+	unsigned char  *buffer;
+	IO::filesize_t  length;
 	
 	void reset () {
 	    xmlFree (buffer);
