@@ -1,4 +1,4 @@
-//$Id: edit-ops.cc,v 1.9 2005/10/17 13:52:18 cactus Exp $ -*- c++ -*-
+//$Id: edit-ops.cc,v 1.10 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
+#include <glib.h>
 
 #include "edit-ops.h"
 #include "edit-priv.h"
