@@ -1,4 +1,4 @@
-//$Id: auto-resizeable-prop.cc,v 1.8 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
+//$Id: auto-resizeable-prop.cc,v 1.9 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "auto-resizeable-prop.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "widgets/size-entry.h"
 #include "widgets/auto-toggle.h"
