@@ -1,4 +1,4 @@
-//$Id: button-prop.cc,v 1.33 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
+//$Id: button-prop.cc,v 1.34 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "button-prop.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "widgets/num-entry.h"
 #include "widgets/togglebutton.h"
