@@ -1,4 +1,4 @@
-//$Id: disabled-prop.cc,v 1.2 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
+//$Id: disabled-prop.cc,v 1.3 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "disabled-prop.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "property-ops-widget.h"
 
