@@ -1,6 +1,6 @@
-//$Id: font.cc,v 1.26 2004/08/31 12:50:40 cactus Exp $ -*- c++ -*-
+//$Id: font.cc,v 1.29 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -225,6 +225,11 @@ void Font::parse (std::istream &stream)
     empty_glyph = new Glyph (line_height, ascent);
 }
 
+Font::~Font ()
+{
+    delete empty_glyph;
+}
+
 const Glyph& Font::get_glyph (char c) const
 {
     std::hash_map<char, Glyph>::const_iterator found_glyph = glyphs.find (c);
@@ -244,7 +249,7 @@ int Font::get_line_width (const std::string &text) const
 	char c = next_char (text, i);
 	const Glyph &g = get_glyph (c);
 	
-	width += g.width;
+	width += g.get_width ();
     }
     
     return width;
@@ -259,7 +264,7 @@ int Font::get_raw_line_width (const std::string &text) const
     {
 	const Glyph &g = get_glyph (*i);
 	
-	width += g.width;
+	width += g.get_width ();
     }
     
     return width;
