@@ -1,4 +1,4 @@
-//$Id: form-canvas.h,v 1.13 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
+//$Id: form-canvas.h,v 1.14 2005/11/04 19:35:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -45,7 +45,6 @@ namespace Guikachu
 	    {		
 		Resources::Form    *res;
 
-		FooCanvasmm::Item  *background_item;
 		FooCanvasmm::Group *frame_group;
 		FooCanvasmm::Group *title_group;
 		FooCanvasmm::Group *widget_group;
@@ -66,7 +65,6 @@ namespace Guikachu
 		
 	    private:
 		/* Drawing methods */
-		void draw_background ();
 		void draw_frame ();
 		void draw_title ();
 		
