@@ -1,4 +1,4 @@
-//$Id: list-prop.cc,v 1.26 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
+//$Id: list-prop.cc,v 1.27 2005/11/22 23:14:25 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "list-prop.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "widgets/entry.h"
 #include "widgets/num-entry.h"
