@@ -1,4 +1,4 @@
-//$Id: palette.cc,v 1.25 2005/11/15 23:43:39 cactus Exp $ -*- c++ -*-
+//$Id: palette.cc,v 1.26 2005/11/22 23:14:25 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "palette.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include <gtkmm/table.h>
 #include <gtkmm/image.h>
