@@ -1,6 +1,6 @@
-//$Id: resizeable.h,v 1.14 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: resizeable.h,v 1.16 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -23,12 +23,14 @@
 #include <sigc++/object.h>
 #include "property.h"
 #include "form-element.h"
+#include "moveable.h"
 
 namespace Guikachu
 {
     namespace Widgets
     {
-	class Resizeable: public virtual FormElement
+	class Resizeable: public virtual FormElement,
+                          public virtual Moveable
 	{
 	protected:
 	    Resizeable (Property<int> &real_width,
@@ -36,7 +38,7 @@ namespace Guikachu
 	    
 	public:
 	    virtual ~Resizeable () {};
-	    
+
 	    virtual int get_width  () const;
 	    virtual int get_height () const;
 
