@@ -1,6 +1,6 @@
-//$Id: scrollbar.cc,v 1.27 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.cc,v 1.29 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -24,11 +24,11 @@ using Guikachu::Widgets::ScrollBar;
 ScrollBar::ScrollBar (Resources::Form   *owner,
 		      const std::string &id,
 		      serial_t           serial):
-    Widget (owner, id, serial),
     ResizeableWidget (changed),
+    Widget (owner, id, serial),
     AutoWidth (changed),
+    Usable (changed),
     
-    usable (changed, true),
     min_value (changed, 0),
     max_value (changed, 0),
     value (changed, 0),
