@@ -1,4 +1,4 @@
-//$Id: selector-trigger-prop.cc,v 1.19 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-prop.cc,v 1.20 2005/11/22 23:14:25 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "selector-trigger-prop.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "auto-resizeable-prop.h"
 #include "usable-prop.h"
