@@ -1,4 +1,4 @@
-//$Id: form-win-edit.cc,v 1.5 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: form-win-edit.cc,v 1.6 2005/10/17 13:52:18 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,3 +42,13 @@ void FormWindow::widget_paste_cb ()
 {
     Edit::paste_widgets (res);
 }
+
+void FormWindow::widget_duplicate_cb (Widget *widget)
+{
+    if (!widget || selection.find (widget) != selection.end ())
+    {
+	Edit::duplicate_widgets (selection);
+    } else {
+	Edit::duplicate_widget (widget);
+    }    
+}
