@@ -1,4 +1,4 @@
-//$Id: form-win-helpers.cc,v 1.24 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: form-win-helpers.cc,v 1.25 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "form-win-helpers.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include <sigc++/bind_return.h>
 
