@@ -1,6 +1,6 @@
-//$Id: form-win-widgettree.h,v 1.5 2004/06/26 17:00:43 cactus Exp $ -*- c++ -*-
+//$Id: form-win-widgettree.h,v 1.7 2005/10/03 14:50:06 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -78,6 +78,9 @@ namespace Guikachu
 
 		void button_press_cb (GdkEventButton *e);
                 void key_press_cb (GdkEventKey *e);
+                
+                Gtk::TreeStore::iterator get_place (Guikachu::Widget *widget) const;
+                bool compare_treerow (const Gtk::TreeRow &row, Guikachu::Widget *widget) const;
 	    };
 	}
     }
