@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.75 2005/11/10 20:13:10 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.76 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "form-win.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "form-editor/palette.h"
 
