@@ -1,4 +1,4 @@
-//$Id: form-win.h,v 1.44 2005/10/17 13:52:18 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.45 2005/11/10 20:13:10 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -63,10 +63,8 @@ namespace Guikachu
 	    FormWindow_Helpers::CanvasSelectionWrapper *selection_canvas;
 	    FormWindow_Helpers::WidgetTreeWrapper      *widget_tree;
 
-	    Widget    *edited_widget;
-	    Widget    *last_widget;
-	    Gtk::Menu *form_popup_menu;
-	    Gtk::Menu *widget_popup_menu;
+	    Widget *edited_widget;
+	    Widget *last_widget;
 
 	    typedef std::set<Widget*> selection_t;
 	    selection_t               selection;
