@@ -1,4 +1,4 @@
-//$Id: gnome-i18n-cnp.cc,v 1.4 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: gnome-i18n-cnp.cc,v 1.6 2005/11/29 21:16:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  *
@@ -22,6 +22,9 @@
 
 #include "gnome-i18n-cnp.h"
 
+#include "config.h"
+#include <glib/gi18n.h>
+
 #include <stdio.h>
 #include <glib.h>
 #include <locale.h>
@@ -69,7 +72,9 @@ namespace
 	int i;
 	if (!alias_table)
 	{
+#ifdef GUIKACHU_HAVE_LIBGNOMEUI
 	    read_aliases (LIBGNOME_DATADIR "/locale/locale.alias");
+#endif
 	    read_aliases ("/usr/share/locale/locale.alias");
 	    read_aliases ("/usr/local/share/locale/locale.alias");
 	    read_aliases ("/usr/lib/X11/locale/locale.alias");
