@@ -1,4 +1,4 @@
-//$Id: gnome-i18n-cnp.h,v 1.4 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: gnome-i18n-cnp.h,v 1.5 2005/11/29 21:16:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  *
@@ -23,13 +23,6 @@
 #include <list>
 #include <string>
 
-#ifdef ENABLE_NLS
-#    include <libintl.h>
-#else
-#    define gettext(String) (String)
-#endif
-#define _(String) gettext (String)
-
 namespace Guikachu
 {
     std::list<std::string> get_language_list (std::string category_name);
