@@ -1,4 +1,4 @@
-//$Id: bmp-saver.h,v 1.2 2005/07/29 09:54:17 cactus Exp $ -*- c++ -*-
+//$Id: bmp-saver.h,v 1.3 2005/11/24 21:54:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,7 +19,7 @@
 #ifndef GUIKACHU_IO_BMP_SAVER_H
 #define GUIKACHU_IO_BMP_SAVER_H
 
-#include <libgnomevfsmm/types.h>
+#include "io/io.h"
 #include <gdkmm/pixbuf.h>
 
 namespace Guikachu
@@ -27,7 +27,7 @@ namespace Guikachu
     namespace IO
     {
         void save_bmp (const Glib::RefPtr<Gdk::Pixbuf> &pixbuf,
-                       unsigned char *&data, Gnome::Vfs::FileSize &len) throw (Glib::Exception);
+                       unsigned char *&data, filesize_t &len) throw (Glib::Exception);
     }
 }
 
