@@ -1,4 +1,4 @@
-//$Id: xml-loader.h,v 1.11 2005/07/29 09:54:17 cactus Exp $ -*- c++ -*-
+//$Id: xml-loader.h,v 1.12 2005/11/27 18:24:25 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -46,9 +46,10 @@ namespace Guikachu
 	    class ResourceLoader: public ResourceVisitor
 	    {
 		const StorageNode &node;
+                Glib::ustring      src_hint;
 		
 	    public:
-		explicit ResourceLoader (const StorageNode &node);
+		explicit ResourceLoader (const StorageNode &node, const Glib::ustring &src_hint = Glib::ustring ());
 	    
 		void visit_resource (Resources::Dialog       *res);
 		void visit_resource (Resources::String       *res);
@@ -63,8 +64,10 @@ namespace Guikachu
 	    class WidgetLoader: public WidgetVisitor
 	    {
 		const StorageNode &node;
+                Glib::ustring      src_hint;
+                
 	    public:
-		WidgetLoader (const StorageNode &node);
+		WidgetLoader (const StorageNode &node, const Glib::ustring &src_hint = Glib::ustring ());
 		
 		void visit_widget (Widgets::Label           *widget);
 		void visit_widget (Widgets::Button          *widget);
