@@ -1,4 +1,4 @@
-//$Id: xml-saver.h,v 1.10 2005/07/29 09:54:17 cactus Exp $ -*- c++ -*-
+//$Id: xml-saver.h,v 1.11 2005/11/27 18:24:25 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -38,10 +38,11 @@ namespace Guikachu
 	{
 	    class ResourceSaver: public ResourceVisitor
 	    {
-		StorageNode &node;
+		StorageNode   &node;
+                Glib::ustring  src_hint;
 		
 	    public:
-		explicit ResourceSaver (StorageNode &node);
+		explicit ResourceSaver (StorageNode &node, const Glib::ustring &src_hint = Glib::ustring ());
 	    
 		void visit_resource (Resources::Dialog       *res);
 		void visit_resource (Resources::String       *res);
@@ -55,10 +56,11 @@ namespace Guikachu
 	    
 	    class WidgetSaver: public WidgetVisitor
 	    {
-		StorageNode &node;
+		StorageNode   &node;
+                Glib::ustring  src_hint;
 		
 	    public:
-		explicit WidgetSaver (StorageNode &node);
+		explicit WidgetSaver (StorageNode &node, const Glib::ustring &src_hint = Glib::ustring ());
 		
 		void visit_widget (Widgets::Label           *widget);
 		void visit_widget (Widgets::Button          *widget);
