@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.27 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.28 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include <libglademm/xml.h>
 #include <fcntl.h>
@@ -142,10 +141,5 @@ int main (int argc, char **argv)
     if (!check_files ())
 	return -1;
 
-#ifdef GUIKACHU_USE_WM_ICONS
-    // FIXME
-    gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/guikachu.png");
-#endif
-    
     app.run ();
 }
