@@ -1,4 +1,4 @@
-//$Id: mainwin-edit.cc,v 1.7 2005/10/15 09:52:30 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-edit.cc,v 1.8 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "mainwin.h"
 
