@@ -1,4 +1,4 @@
-//$Id: mainwin-io.cc,v 1.43 2005/11/05 11:24:52 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.46 2005/11/29 21:16:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "mainwin.h"
 #include "ui.h"
@@ -32,7 +31,7 @@
 #include <gtkmm/image.h>
 #include <gtkmm/button.h>
 #include <gtkmm/box.h>
-#include <gtkmm/filechooserdialog.h>
+#include "widgets/filechooserdialog.h"
 
 #include "io/rcp-saver.h"
 
@@ -132,7 +131,7 @@ bool GUI::MainWin::check_save ()
 
     if (response == discard_btn_num)
 	if (in_exit)
-	    Gnome::Main::quit ();
+	    Gtk::Main::quit ();
     
     if (response == save_btn_num)
     {
@@ -169,14 +168,15 @@ void GUI::MainWin::save_cb ()
 
 void GUI::MainWin::save_as_cb ()
 {
-    Gtk::FileChooserDialog file_chooser (*this, _("Save Guikachu file"), Gtk::FILE_CHOOSER_ACTION_SAVE);
-    file_chooser.add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-    file_chooser.add_button (Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
-    file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
+    FileChooserDialog file_chooser (*this, _("Save Guikachu file"), Gtk::FILE_CHOOSER_ACTION_SAVE);
 
     Gtk::FileFilter filter_guikachu;
     filter_guikachu.set_name (_("Guikachu documents"));
+#ifdef GUIKACHU_HAVE_GNOMEVFS
     filter_guikachu.add_mime_type ("application/x-guikachu");
+#else
+    filter_guikachu.add_pattern ("*.guikachu");
+#endif
     file_chooser.add_filter (filter_guikachu);
 
     Gtk::FileFilter filter_all;
@@ -184,44 +184,47 @@ void GUI::MainWin::save_as_cb ()
     filter_all.add_pattern ("*");
     file_chooser.add_filter (filter_all);
     
-    file_chooser.set_local_only (false);
     if (UI::confirm_save (file_chooser))
         Guikachu::Main::instance ()->save_doc (file_chooser.get_uri ());
 }
     
 void GUI::MainWin::load_cb ()
 {
-    Gtk::FileChooserDialog file_chooser (*this, _("Select a Guikachu file to open"), Gtk::FILE_CHOOSER_ACTION_OPEN);
-    file_chooser.add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-    file_chooser.add_button (Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT);
-    file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
+    FileChooserDialog file_chooser (*this, _("Select a Guikachu file to open"), Gtk::FILE_CHOOSER_ACTION_OPEN);
     
     Gtk::FileFilter filter_guikachu;
     filter_guikachu.set_name (_("Guikachu documents"));
+#ifdef GUIKACHU_HAVE_GNOMEVFS
     filter_guikachu.add_mime_type ("application/x-guikachu");
+#else
+    filter_guikachu.add_pattern ("*.guikachu");
+#endif
     file_chooser.add_filter (filter_guikachu);
     
     Gtk::FileFilter filter_rcp;
     filter_rcp.set_name (_("PilRC documents"));
+#ifdef GUIKACHU_HAVE_GNOMEVFS
     filter_rcp.add_mime_type ("text/x-rcp");
+#else
+    filter_guikachu.add_pattern ("*.rcp");
+#endif
     file_chooser.add_filter (filter_rcp);
 
-    file_chooser.set_local_only (false);
-
     if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
         open (file_chooser.get_uri ());
 }
     
 void GUI::MainWin::export_cb ()
 {
-    Gtk::FileChooserDialog file_chooser (*this, _("Export to RCP"), Gtk::FILE_CHOOSER_ACTION_SAVE);
-    file_chooser.add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-    file_chooser.add_button (Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
-    file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
+    FileChooserDialog file_chooser (*this, _("Export to RCP"), Gtk::FILE_CHOOSER_ACTION_SAVE);
 
     Gtk::FileFilter filter_rcp;
     filter_rcp.set_name (_("PilRC documents"));
+#ifdef GUIKACHU_HAVE_GNOMEVFS
     filter_rcp.add_mime_type ("text/x-rcp");
+#else
+    filter_rcp.add_pattern ("*.rcp");
+#endif
     file_chooser.add_filter (filter_rcp);
 
     Gtk::FileFilter filter_all;
@@ -229,7 +232,6 @@ void GUI::MainWin::export_cb ()
     filter_all.add_pattern ("*");
     file_chooser.add_filter (filter_all);
     
-    file_chooser.set_local_only (false);
     if (file_chooser.run () != Gtk::RESPONSE_ACCEPT)
         return;
     
