@@ -1,4 +1,4 @@
-//$Id: menu-res-ops.cc,v 1.10 2005/11/03 21:38:40 cactus Exp $ -*- c++ -*-
+//$Id: menu-res-ops.cc,v 1.11 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "menu-res-ops.h"
 #include <glib.h> // for g_assert
