@@ -1,4 +1,4 @@
-//$Id: menu-res.h,v 1.26 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.h,v 1.28 2005/10/28 18:46:28 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,6 +36,9 @@ namespace Guikachu
 		std::string id;
 		std::string label;
 		char        shortcut;
+
+                MenuItem ();
+                MenuItem (const std::string &id, const std::string &label, char shortcut = 0);
 	    };
 
 	    typedef std::vector<MenuItem> MenuItems;
@@ -46,7 +49,7 @@ namespace Guikachu
 		MenuItems   items;
 		
 		Submenu () {};
-		Submenu (const std::string& label);
+		explicit Submenu (const std::string& label);
 	    };
 	    
 	    typedef std::vector<Submenu> MenuTree;
