@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.52 2005/11/10 21:43:47 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.54 2005/11/29 21:16:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,8 +20,7 @@
 #include "menu-win-treemodel.h"
 #include "widgets/dropdown-button.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "property-ops-resource.h"
 #include "menu-res-ops.h"
@@ -66,8 +65,8 @@ GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
     Gtk::Container *preview_frame;
     gui->get_widget ("menu_preview_frame", preview_frame);
     FooCanvasmm::Canvas *canvas = new ScreenCanvas (res->get_manager ()->get_target ());
-    FooCanvasmm::Item *bg = new FormEditor::ScreenCanvasItem (*canvas->root (), res->get_manager ()->get_target ());
-    FooCanvasmm::Item *item = new FormEditor::MenubarCanvasItem (*canvas->root (), res);
+    new FormEditor::ScreenCanvasItem (*canvas->root (), res->get_manager ()->get_target ());
+    new FormEditor::MenubarCanvasItem (*canvas->root (), res);
 
     preview_frame->add (*manage (canvas));
     
