@@ -1,4 +1,4 @@
-//$Id: menu-win.h,v 1.19 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.h,v 1.24 2005/11/05 11:53:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,13 +25,13 @@
 #include <gtkmm/window.h>
 #include <gtkmm/entry.h>
 #include <gtkmm/button.h>
-#include <gtkmm/label.h>
 #include <gtkmm/treeview.h>
-#include <gtkmm/liststore.h>
+#include <gtkmm/menu.h>
 
 #include <libglademm/xml.h>
 
-#include <vector>
+#include "menu-win-treemodel.h"
+#include "menu-win-stock.h"
 
 namespace Guikachu
 {
@@ -48,17 +48,17 @@ namespace Guikachu
 	    Gtk::TreeView *treeview;
 	    
 	    Gtk::Entry  *id_entry;
-	    Gtk::Button *btnUp, *btnDown, *btnRemove;
-	    Gtk::Entry  *item_label, *item_id, *item_shortcut;
-	    Gtk::Label  *lbl_item_label, *lbl_item_id, *lbl_item_shortcut;
-	    Gtk::Button *btnSubmenu, *btnItem, *btnSeparator;
+	    Gtk::Button *btnRemove, *btnUp, *btnDown;
+            Gtk::Widget *btnSubmenu, *btnItem;
+            Gtk::Menu   *popup_menu, *dropdown_menu;
 
 	    Gtk::TreeModelColumn<bool>          col_is_submenu;
-	    Gtk::TreeModelColumn<unsigned int>  col_index;
-	    Gtk::TreeModelColumn<unsigned int>  col_parent_index;
-	    Glib::RefPtr<Gtk::ListStore>        treestore;
+            Gtk::TreeModelColumn<Glib::ustring> col_label;
+            Gtk::TreeModelColumn<Glib::ustring> col_id;
+            Gtk::TreeModelColumn<char>          col_shortcut;
+            Gtk::TreeModelColumn<bool>          col_is_separator;
 
-	    Resources::Menu::MenuTree submenus;
+            Glib::RefPtr<MenuWindow_Helpers::MenuTreeModel> treemodel;
 	    
 	public:
 	    MenuWindow (Guikachu::Resources::Menu *res);
@@ -72,11 +72,10 @@ namespace Guikachu
 	    int         update_block;
 
 	    void update ();
+
+            void create_columns ();
             
 	    void id_entry_cb ();
-	    void item_label_entry_cb ();
-	    void item_id_entry_cb ();
-	    void item_shortcut_entry_cb ();
 
             void cell_label_cb    (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const;
             void cell_id_cb       (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const;
@@ -87,32 +86,25 @@ namespace Guikachu
             void cell_shortcut_edit_cb (const Glib::ustring &path, const Glib::ustring &new_text);
             
 	    void delete_event_impl (GdkEventAny *e);
+
+            void button_press_cb   (GdkEventButton *e);
+	    void key_press_cb      (GdkEventKey    *e);
+            void show_popup_menu   (guint button, guint32 time);
             
 	    void reset_controls ();
 
             void entry_insert_cb (const Glib::ustring &text, int *pos, Gtk::Entry *entry);
             void entry_delete_cb (int start_pos, int end_pos, Gtk::Entry *entry);
             
-            void set_item_label    (const Gtk::TreeModel::iterator &iter, const std::string &new_label);
-            void set_item_id       (const Gtk::TreeModel::iterator &iter, const std::string &new_id);
-            void set_item_shortcut (const Gtk::TreeModel::iterator &iter, const std::string &new_shortcut);
-            
-	    void btn_up_cb ();
-	    void btn_down_cb ();
 	    void btn_remove_cb ();
-
-	    void btn_submenu_cb ();
-	    void btn_item_cb (bool separator);
+            void btn_up_cb ();
+            void btn_down_cb ();
+            
+	    void create_submenu_cb ();
+            void create_stock_submenu_cb (MenuWindow_Helpers::StockMenu stock_id);
+	    void create_item_cb (bool separator);
 
 	    void selection_changed_cb ();
-	    
-	    void submenu_up     (unsigned int index);
-	    void submenu_down   (unsigned int index);
-	    void submenu_remove (unsigned int index);
-	    
-	    void menuitem_up     (unsigned int parent_index, unsigned int index);
-	    void menuitem_down   (unsigned int parent_index, unsigned int index);
-	    void menuitem_remove (unsigned int parent_index, unsigned int index);
 	};
     }
 }
