@@ -1,4 +1,4 @@
-//$Id: preferences-win.cc,v 1.13 2005/11/10 21:43:26 cactus Exp $ -*- c++ -*-
+//$Id: preferences-win.cc,v 1.14 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,8 +19,7 @@
 #include "preferences-win.h"
 #include "preferences.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include <gtkmm/adjustment.h>
 
