@@ -1,4 +1,4 @@
-//$Id: preferences.cc,v 1.21 2005/11/10 21:43:26 cactus Exp $ -*- c++ -*-
+//$Id: preferences.cc,v 1.23 2005/11/27 14:57:58 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,53 +18,46 @@
 
 #include "preferences.h"
 
-#include <gconfmm/client.h>
+namespace {
+    void init ();
+
+    int get_conf_int   (const std::string &path, const std::string &key, int default_value = 0);
+    bool get_conf_bool (const std::string &path, const std::string &key, bool default_value = false);
+    
+    float get_conf_float (const std::string &path, const std::string &key, float default_value = 0);
+    void set_conf_float  (const std::string &path, const std::string &key, float value);
+
+    std::string get_conf_string (const std::string &path, const std::string &key, const std::string &default_value = "");
+    void set_conf_string (const std::string &path, const std::string &key, const std::string &value);
+
+    typedef Guikachu::Preferences::Interface::RecentFiles FileList;
+    
+    FileList get_conf_filelist (const std::string &path, const std::string &key);
+    void set_conf_filelist     (const std::string &path, const std::string &key, const FileList &value);
+} // anonymous namespace
+
+#include "config.h"
+
+#ifdef GUIKACHU_CONFIG_SYSTEM_GCONF
+#include "preferences-gconf.cc"
+#else
+#ifdef GUIKACHU_CONFIG_SYSTEM_WINREG
+#include "preferences-winreg.cc"
+#else
+#error "Unknown config system"
+#endif
+#endif
+
+
 #include <algorithm>
 
-namespace Guikachu
-{
-    namespace Preferences
-    {
-	Glib::RefPtr<Gnome::Conf::Client> gconf_client;
-
-	static std::string get_gconf_string (const std::string &key);
-    }
-}
-
-#define GCONF_ROOT        "/apps/guikachu"
-#define GCONF_COLORS_ROOT "/FormEditor/Colors"
-
 using namespace Guikachu;
 
-void Preferences::init ()
-{
-    // Set up GConf client
-    gconf_client = Gnome::Conf::Client::get_default_client ();
-    gconf_client->add_dir ("/apps/guikachu", Gnome::Conf::CLIENT_PRELOAD_RECURSIVE);
-    
-    // Set up GConf callbacks
-    // User interface
-    gconf_client->notify_add (GCONF_ROOT "/Interface",
-                              sigc::hide (sigc::hide (Interface::recent_files_changed.make_slot ())));
-    
-    // Colors
-    gconf_client->notify_add (GCONF_ROOT GCONF_COLORS_ROOT,
-                              sigc::hide (sigc::hide (FormEditor::colors_changed.make_slot ())));
-}
-
-std::string Preferences::get_gconf_string (const std::string &key)
-{
-    std::string real_key = GCONF_ROOT + key;
-    return gconf_client->get_string (real_key);;
-}
-
-
-
 sigc::signal0<void> Preferences::Interface::recent_files_changed;
 
 Preferences::Interface::RecentFiles Preferences::Interface::get_recent_files ()
 {
-    return gconf_client->get_string_list (GCONF_ROOT "/Interface/recent_files");
+    return get_conf_filelist ("Interface", "recent_files");
 }
 
 void Preferences::Interface::add_recent_file (const Glib::ustring &uri)
@@ -81,7 +74,7 @@ void Preferences::Interface::add_recent_file (const Glib::ustring &uri)
     recent_list.push_front (uri);
     
     // Truncate list
-    int recent_list_size = gconf_client->get_int (GCONF_ROOT "/Interface/recent_files_size");
+    int recent_list_size = get_conf_int ("Interface", "recent_files_size", 4);
     int pos;
     RecentFiles::iterator truncate_begin;
 
@@ -93,68 +86,67 @@ void Preferences::Interface::add_recent_file (const Glib::ustring &uri)
     if (truncate_begin != recent_list.end ())
 	recent_list.erase (truncate_begin, recent_list.end ());
 
-    Gnome::Conf::Value gval (Gnome::Conf::VALUE_LIST);
-    gval.set_list_type (Gnome::Conf::VALUE_STRING);
-    gval.set_string_list (recent_list);
-
-    gconf_client->set (GCONF_ROOT "/Interface/recent_files", gval);
+    set_conf_filelist ("Interface", "recent_files", recent_list);
+    recent_files_changed.emit ();
 }
 
 int Preferences::Interface::get_undo_size ()
 {
-    return gconf_client->get_int (GCONF_ROOT "/Interface/undo_size");
+    return get_conf_int ("Interface", "undo_size", 20);
 }
 
 bool Preferences::MainWin::get_default_grouped ()
 {
-    return gconf_client->get_bool (GCONF_ROOT "/MainWin/default_grouped");
+    return get_conf_bool ("MainWin", "default_grouped", true);
 }
 
 
 sigc::signal0<void> Preferences::FormEditor::colors_changed;
 
+#define CONF_COLORS_ROOT "FormEditor/Colors"
+
 void Preferences::FormEditor::set_colors (const std::string &color_fg,
 					  const std::string &color_disabled,
 					  const std::string &color_bg,
 					  const std::string &color_selection)
 {
-#define SET_COLOR(key,value) gconf_client->set (GCONF_ROOT "/FormEditor/Colors/" key, value)
-
+#define SET_COLOR(key,value) set_conf_string (CONF_COLORS_ROOT, key, value)
+    
     SET_COLOR("foreground", color_fg);
     SET_COLOR("foreground_disabled", color_disabled);
     SET_COLOR("background", color_bg);
     SET_COLOR("selection", color_selection);
 
 #undef SET_COLOR
-    
+    colors_changed.emit ();
 }
 
 std::string Preferences::FormEditor::get_color_fg ()
 {
-    return get_gconf_string (GCONF_COLORS_ROOT "/foreground");
+    return get_conf_string (CONF_COLORS_ROOT, "foreground", "#000000");
 }
 
 std::string Preferences::FormEditor::get_color_disabled ()
 {
-    return get_gconf_string (GCONF_COLORS_ROOT "/foreground_disabled");
+    return get_conf_string (CONF_COLORS_ROOT, "foreground_disabled", "#757575");
 }
 
 std::string Preferences::FormEditor::get_color_bg ()
 {
-    return get_gconf_string (GCONF_COLORS_ROOT "/background");
+    return get_conf_string (CONF_COLORS_ROOT, "background", "#90b398");
 }
 
 std::string Preferences::FormEditor::get_color_selection ()
 {
-    return get_gconf_string (GCONF_COLORS_ROOT "/selection");
+    return get_conf_string (CONF_COLORS_ROOT, "selection", "#ecffa8");
 }
 
 float Preferences::FormEditor::get_default_zoom ()
 {
-    return gconf_client->get_float (GCONF_ROOT "/FormEditor/default_zoom");
+    return get_conf_float ("FormEditor", "default_zoom", 1.0);
 }
 
 void Preferences::FormEditor::set_default_zoom (float default_zoom)
 {
-    gconf_client->set (GCONF_ROOT "/FormEditor/default_zoom", default_zoom);
+    set_conf_float ("FormEditor", "default_zoom", default_zoom);
 }
