@@ -1,4 +1,4 @@
-//$Id: queued-signal.cc,v 1.7 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: queued-signal.cc,v 1.8 2005/10/15 09:52:31 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  *
@@ -23,9 +23,6 @@
 #include <glibmm/main.h>
 #include <sigc++/bind_return.h>
 
-#include <iostream>
-#include <gdk/gdkevents.h>
-
 using namespace Guikachu;
 
 namespace
