@@ -16,8 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "resource-tree.h"
 
@@ -245,20 +244,17 @@ void ResourceTree::resource_created_cb (Resource *res)
 
     if (row_map.find (res) == row_map.end ())
     {    
-        res->changed.connect (sigc::bind (sigc::mem_fun (*this, &ResourceTree::resource_changed_cb), row));
+        res->changed.connect (sigc::bind (sigc::mem_fun (*this, &ResourceTree::resource_changed_cb), res));
     }    
     row_map[res] = row;
 
     expand_all ();
 }
 
-void ResourceTree::resource_changed_cb (Gtk::TreeRow row)
+void ResourceTree::resource_changed_cb (Resource *res)
 {
+    Gtk::TreeRow row = row_map[res];
     bool selected = get_selection ()->is_selected (row);
-
-    const TreeData &td = row[col_data];
-    Resource *res = td.get_resource ();
-    g_return_if_fail (res);
     
     treestore->erase (row);
     row = *(treestore->insert (get_place (res)));
