@@ -1,4 +1,4 @@
-//$Id: resource-util.cc,v 1.16 2005/11/05 11:24:52 cactus Exp $ -*- c++ -*-
+//$Id: resource-util.cc,v 1.17 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "resource-util.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 using namespace Guikachu;
 
