@@ -1,4 +1,4 @@
-//$Id: target.cc,v 1.18 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: target.cc,v 1.19 2005/11/22 23:14:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "target.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "storage.h"
 #include <glib.h> // For g_warning
