@@ -1,4 +1,4 @@
-//$Id: ui-gui.cc,v 1.15 2005/11/05 08:20:22 cactus Exp $ -*- c++ -*-
+//$Id: ui-gui.cc,v 1.17 2005/11/27 18:24:24 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "ui-gui.h"
 #include "session.h"
@@ -30,6 +29,11 @@
 #include <gtkmm/main.h>
 #include <gtkmm/aboutdialog.h>
 
+#include "config.h"
+#ifdef GUIKACHU_HAVE_LIBGNOMEUI
+#include <libgnome/gnome-url.h>
+#endif
+
 #include <list>
 #include <iostream>
 
@@ -47,10 +51,13 @@ void UI::flush_events ()
 }
 
 namespace {
+#ifdef GUIKACHU_HAVE_LIBGNOMEUI
     void about_uri_cb (Gtk::AboutDialog &about, const Glib::ustring &uri)
     {
         gnome_url_show (uri.c_str (), 0);
     }
+#endif
+    
 } // anonymous namespace
 
 void UI::show_about (Gtk::Window *parent)
@@ -86,8 +93,10 @@ void UI::show_about (Gtk::Window *parent)
         "59 Temple Place, Suite 330, Boston, MA 02111-1307 USA";
     
     Gtk::AboutDialog *about = new Gtk::AboutDialog;
+#ifdef GUIKACHU_HAVE_LIBGNOMEUI
     about->set_url_hook (sigc::ptr_fun (about_uri_cb));
-
+#endif
+    
     about->set_name ("Guikachu");
     about->set_version (VERSION);
     about->set_copyright ("Copyright \xC2\xA9 2001-2005 Gerg\xC5\x91 \xC3\x89rdi");
@@ -137,6 +146,69 @@ void UI::show_warning (const Glib::ustring &full_message,
     }
 }
 
+void UI::show_error_io_open (const Glib::ustring &uri, const Glib::ustring &error_msg)
+{    
+    char *buffer = g_strdup_printf (
+	_("<big><b>Unable to open \"%s\"</b></big>\n"
+          "%s"),
+	UI::visible_filename (uri).c_str () , error_msg.c_str ());
+
+    UI::show_error (buffer, uri + ":" + error_msg);
+    g_free (buffer);
+}
+    
+void UI::show_error_io_save (const Glib::ustring &uri, const Glib::ustring &error_msg)
+{    
+    char *buffer = g_strdup_printf (
+	_("<big><b>Unable to save \"%s\"</b></big>\n"
+          "%s"),
+	UI::visible_filename (uri).c_str (), error_msg.c_str ());
+
+    UI::show_error (buffer, uri + ":" + error_msg);
+    g_free (buffer);
+}
+
+void UI::show_error_io_load_resource (const Glib::ustring &uri, const std::string &id,
+                                      const Glib::ustring &error_msg)
+{
+    char *buffer;
+
+    if (id == "")
+        buffer = g_strdup_printf (
+            _("<big><b>Error while loading \"%s\"</b></big>\n"
+              "%s"),
+            id.c_str (), error_msg.c_str ());
+    else
+        buffer = g_strdup_printf (
+            _("<big><b>Error while loading \"%s\" from \"%s\"</b></big>\n"
+              "%s"),
+            id.c_str (), UI::visible_filename (uri).c_str (), error_msg.c_str ());
+
+    UI::show_error (buffer, uri + ":" + error_msg);
+    g_free (buffer);
+}
+
+void UI::show_error_io_save_resource (const Glib::ustring &uri, const std::string &id,
+                                      const Glib::ustring &error_msg)
+{
+    char *buffer;
+
+    if (id == "")
+        buffer = g_strdup_printf (
+            _("<big><b>Error while saving \"%s\"</b></big>\n"
+              "%s"),
+            id.c_str (), error_msg.c_str ());
+    else
+        buffer = g_strdup_printf (
+            _("<big><b>Error while saving \"%s\" to \"%s\"</b></big>\n"
+              "%s"),
+            id.c_str (), UI::visible_filename (uri).c_str (), error_msg.c_str ());
+
+    UI::show_error (buffer, uri + ":" + error_msg);
+    g_free (buffer);
+}
+
+
 Gtk::Button * UI::create_stock_button (const Gtk::StockID  &stock_id,
                                        const Glib::ustring &title)
 {
