@@ -1,4 +1,4 @@
-//$Id: ui-gui.h,v 1.5 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: ui-gui.h,v 1.6 2005/11/03 22:49:44 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,7 +29,7 @@ namespace Guikachu
 {
     namespace UI
     {
-	void show_about ();
+	void show_about (Gtk::Window *parent = 0);
 
         Gtk::Button * create_stock_button (const Gtk::StockID  &stock_id,
                                            const Glib::ustring &title);
