@@ -1,6 +1,6 @@
-//$Id: auto-toggle.h,v 1.8 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: auto-toggle.h,v 1.10 2005/07/29 09:54:19 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -31,8 +31,8 @@ namespace Guikachu
     {
 	namespace PropertyEditors
 	{
-	    class AutoToggle: public PropertyEditor,
-			      public Gtk::HBox
+	    class AutoToggle: public Gtk::HBox,
+                              public PropertyEditor
 	    {
 		Gtk::CheckButton  togglebutton;
 		Gtk::Widget      &widget;
