@@ -1,6 +1,6 @@
-//$Id: font-combo.h,v 1.6 2004/08/31 12:50:40 cactus Exp $ -*- c++ -*-
+//$Id: font-combo.h,v 1.8 2005/07/29 09:54:19 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -33,8 +33,8 @@ namespace Guikachu
     {
 	namespace PropertyEditors
 	{
-	    class FontCombo: public PropertyEditor,
-			     public Gtk::ComboBox
+	    class FontCombo: public Gtk::ComboBox,
+                             public PropertyEditor
 	    {
 		typedef Property<int>            property_t;
 		typedef PropChangeOpFactory<int> op_factory_t;
