@@ -1,6 +1,6 @@
-//$Id: property-editor.h,v 1.6 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: property-editor.h,v 1.8 2005/07/29 09:54:19 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -35,11 +35,13 @@ namespace Guikachu
 	class PropertyEditor
 	{
 	protected:
-	    PropertyEditor () {};
+	    PropertyEditor ();
 	    PropertyEditor (Gtk::Widget *underline_widget);
 	    
 	    Gtk::Widget *underline_widget;
 	public:
+            virtual ~PropertyEditor () {};
+            
 	    virtual LabelAlignment get_label_alignment () { return LABEL_ALIGN_CENTER; };
 	    virtual bool           get_resizeable ()      { return false; };
 	    virtual void           install_underline (Glib::RefPtr<Gtk::AccelGroup> &accel_group,
