@@ -1,4 +1,4 @@
-//$Id: togglebutton.cc,v 1.12 2005/07/29 09:54:19 cactus Exp $ -*- c++ -*-
+//$Id: togglebutton.cc,v 1.13 2005/11/22 23:14:26 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,7 @@
 
 #include "togglebutton.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 using namespace Guikachu::GUI::PropertyEditors;
 
